/********************************************************************
 * Command Module Header - processes incoming character data, handles the
 * cursor and contains position logic.
 *
 * Commands:
 *   Displayable Character : load character (at current cursor position)
 *      Converts lower-case letters to upper-case
 *   ^H - Backspace : backspace cursor on same line (no change at position 0)
 *   ^I - Tab : forward space cursor
 *   ^J - Line Feed : move cursor to next line (no change on last line)
 *   ^L - Form Feed : clear display
 *   ^M - Carriage Return : move cursor to position 0 on the current line
 *   ^N - Shift Out : set destination to shadow memory
 *   ^O - Shift In : set destination to display
 *   ^Q - DC1 : enable cursor (applies only when destination is display)
 *   ^R - DC2 : disable cursor (applies only when destination is display)
 *   ^S - DC3 : enable cursor blink (applies only when destination is display)
 *   ^T - DC4 : disable cursor blink (applies only when destination is display)
 *   ^V - SIDLE : Display firmware version
 *   ^Z - Substitute : Load shadow memory
 *   DEL - Delete : Change previous character to a blank and backspace
 *   ^[ - Escape : Set Cursor Position
 *      <ESC>COL;ROW'H'  (special case: <ESC>'H' set to home (0,0)
 *
*******************************************************************/
#ifndef CMD_H
#define	CMD_H

#include <xc.h>
#include <stdbool.h>
#include <stdint.h>

// API Routines
void CMD_Init();
void CMD_Tasks(uint8_t timerTick);
void CMD_ProcessChar(uint8_t c);

#endif	/* CMD_H */

