/********************************************************************
 * USB Interface Module - process incoming data from the USB
 * Interface and pass character data to the command processor.
 * 
*******************************************************************/
#include "cmd.h"
#include "sif.h"
#include "usb_if.h"
#include "usb.h"
#include "usb_config.h"
#include "usb_device_cdc.h"
#include <stdlib.h>
#include <stdio.h>


// Command USB variables
uint8_t cmdUSBrxBuffer[CDC_DATA_OUT_EP_SIZE];  // RX Data from USB to process
uint8_t cmdUSBrxBufNum;    // Number of valid bytes in the RX Buffer
uint8_t cmdUSBrxBufIndex;  // Index to current byte being processed

uint8_t cmdUSBtxBuffer[CDC_DATA_IN_EP_SIZE];
uint8_t cmdUSBtxBufNum;


// Internal routine forward declarations
void _USBIF_ClearTxBuffer();
uint8_t _USBIF_GetTxLen();


// API Routines
void USBIF_Init()
{
    // Initialize the USB subsystem
    USBDeviceInit();
    USBDeviceAttach();

    cmdUSBrxBufNum = 0;
    cmdUSBtxBufNum = 0;
}


void USBIF_Tasks()
{
    uint8_t c;

    if ((USBGetDeviceState() == CONFIGURED_STATE) &&
            (USBIsDeviceSuspended() == false)) {

        // Look for new data when we have an available buffer
        if (cmdUSBrxBufNum == 0) {
            cmdUSBrxBufNum = getsUSBUSART(cmdUSBrxBuffer, CDC_DATA_OUT_EP_SIZE);
        }

        // Process data from our buffer when there is room in the SIF TX FIFO
        if ((cmdUSBrxBufNum != 0) && (cmdUSBrxBufNum <= SIF_TxFifoAvail())) {

            cmdUSBrxBufIndex = 0;
            while (cmdUSBrxBufIndex < cmdUSBrxBufNum) {
                c = cmdUSBrxBuffer[cmdUSBrxBufIndex++];

                CMD_ProcessChar(c);

                // Pass it to the next board
                SIF_PushTxChar(c);
            }
            cmdUSBrxBufNum = 0;
        }

        if (cmdUSBtxBufNum != 0) {
            putUSBUSART(cmdUSBtxBuffer, cmdUSBtxBufNum);
            cmdUSBtxBufNum = 0;
        }

        CDCTxService();
    }
}


void USBIF_PrintNum(uint8_t n)
{
    _USBIF_ClearTxBuffer();
    sprintf(cmdUSBtxBuffer, "%d\n", n);
    cmdUSBtxBufNum = _USBIF_GetTxLen();
}


void USBIF_PrintHex(uint8_t n)
{
    _USBIF_ClearTxBuffer();
    sprintf(cmdUSBtxBuffer, "0x%2x\n", n);
    cmdUSBtxBufNum = _USBIF_GetTxLen();
}


void USBIF_PrintString(uint8_t* cP)
{
    _USBIF_ClearTxBuffer();
    sprintf(cmdUSBtxBuffer, "%s\n", cP);
    cmdUSBtxBufNum = _USBIF_GetTxLen();
}


void _USBIF_ClearTxBuffer()
{
    uint8_t i;

    for (i=0; i<CDC_DATA_OUT_EP_SIZE; i++) {
        cmdUSBtxBuffer[i] = 0;
    }
}


uint8_t _USBIF_GetTxLen()
{
    uint8_t i = 0;

    while (cmdUSBtxBuffer[i] != 0) i++;

    return(i);
}
